diff --git a/doc.zih.tu-dresden.de/docs/contrib/contribute_container.md b/doc.zih.tu-dresden.de/docs/contrib/contribute_container.md
index 13fd3516658ba6190c7954d80fbc76b1a8cbef0b..639e03f090f72f518058d705e7b3ebd4cebe2063 100644
--- a/doc.zih.tu-dresden.de/docs/contrib/contribute_container.md
+++ b/doc.zih.tu-dresden.de/docs/contrib/contribute_container.md
@@ -92,8 +92,8 @@ docker build -t hpc-compendium .
 To avoid a lot of retyping, use the following in your shell:
 
 ```bash
-alias wikiscript="docker run --name=hpc-compendium --rm -w /docs --mount src=$PWD,target=/docs,type=bind hpc-compendium"
-alias wiki="docker run --name=hpc-compendium -p 8000:8000 --rm -w /docs --mount src=$PWD/doc.zih.tu-dresden.de,target=/docs,type=bind hpc-compendium"
+alias wikiscript="docker run --name=hpc-compendium --rm -w /docs --mount src=${PWD},target=/docs,type=bind hpc-compendium"
+alias wiki="docker run --name=hpc-compendium -p 8000:8000 --rm -w /docs --mount src=${PWD}/doc.zih.tu-dresden.de,target=/docs,type=bind hpc-compendium"
 ```
 
 ## Working with the Docker Container
diff --git a/doc.zih.tu-dresden.de/util/check-bash-syntax.sh b/doc.zih.tu-dresden.de/util/check-bash-syntax.sh
index ac0fcd4621741d7f094e29aaf772f283b64c284d..e8aa66f5c166a0da8e80be4c25aced52199b3eff 100755
--- a/doc.zih.tu-dresden.de/util/check-bash-syntax.sh
+++ b/doc.zih.tu-dresden.de/util/check-bash-syntax.sh
@@ -3,8 +3,8 @@
 set -euo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-basedir=`dirname "$basedir"`
+basedir=`dirname "${scriptpath}"`
+basedir=`dirname "${basedir}"`
 
 function usage () {
   echo "$0 [options]"
@@ -45,35 +45,35 @@ done
 
 branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-preview}"
 
-if [ $all_files = true ]; then
+if [[ ${all_files} == true ]]; then
   echo "Search in all bash files."
-  files=`git ls-tree --full-tree -r --name-only HEAD $basedir/docs/ | grep '\.sh$' || true`
-elif [[ ! -z $file ]]; then
-  files=$file
+  files=`git ls-tree --full-tree -r --name-only HEAD ${basedir}/docs/ | grep '\.sh$' || true`
+elif [[ ! -z "${file}" ]]; then
+  files=${file}
 else
   echo "Search in git-changed files."
-  files=`git diff --name-only "$(git merge-base HEAD "$branch")" | grep '\.sh$' || true`
+  files=`git diff --name-only "$(git merge-base HEAD "${branch}")" | grep '\.sh$' || true`
 fi
 
 
 cnt=0
-for f in $files; do
-  if ! bash -n $f; then
-    if [ $silent = false ]; then
-      echo "Bash file $f has invalid syntax"
+for f in ${files}; do
+  if ! bash -n ${f}; then
+    if [[ ${silent} == false ]]; then
+      echo "Bash file ${f} has invalid syntax"
     fi
     ((cnt=cnt+1))
   fi
 done
 
-case $cnt in
+case ${cnt} in
   1)
     echo "Bash files with invalid syntax: 1 match found"
   ;;
   *)
-    echo "Bash files with invalid syntax: $cnt matches found"
+    echo "Bash files with invalid syntax: ${cnt} matches found"
   ;;
 esac
-if [ $cnt -gt 0 ]; then
+if [[ ${cnt} -gt 0 ]]; then
   exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/check-empty-page.sh b/doc.zih.tu-dresden.de/util/check-empty-page.sh
index 7c4fdc2cd07b167b39b0b0ece58e199df0df6d84..57fc589fcd404e5e2706636918cf9938ad23fb5c 100755
--- a/doc.zih.tu-dresden.de/util/check-empty-page.sh
+++ b/doc.zih.tu-dresden.de/util/check-empty-page.sh
@@ -3,9 +3,9 @@
 set -euo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-basedir=`dirname "$basedir"`
+basedir=`dirname "${scriptpath}"`
+basedir=`dirname "${basedir}"`
 
-if find $basedir -name \*.md -exec wc -l {} \; | grep '^0 '; then
+if find "${basedir}" -name \*.md -exec wc -l {} \; | grep '^0 '; then
   exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/check-filesize.sh b/doc.zih.tu-dresden.de/util/check-filesize.sh
index fbfcf9049e2dd231ab97ef605eae51a95506e561..70d21f19aca150faf7b98259b825575f7e3c83ca 100755
--- a/doc.zih.tu-dresden.de/util/check-filesize.sh
+++ b/doc.zih.tu-dresden.de/util/check-filesize.sh
@@ -33,22 +33,22 @@
 
 large_files_present=false
 branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-preview}"
-source_hash=`git merge-base HEAD "$branch"`
+source_hash=`git merge-base HEAD "${branch}"`
 lfsfiles=$(git lfs ls-files -n)
 
-for f in $(git diff $source_hash --name-only); do
+for f in $(git diff ${source_hash} --name-only); do
     # Do not check size of git lfs files.
-    if [[ $lfsfiles =~ "$f" ]]; then
+    if [[ ${lfsfiles} =~ "${f}" ]]; then
         echo "Skip file ${f} because it is a git lfs file."
         continue
     fi
-    fs=$(wc -c $f | awk '{print $1}')
-    if [ $fs -gt 1048576 ]; then
-        echo $f 'is over 1M ('$fs' bytes)'
+    fs=$(wc -c ${f} | awk '{print $1}')
+    if [[ ${fs} -gt 1048576 ]]; then
+        echo ${f} 'is over 1M ('${fs}' bytes)'
         large_files_present=true
     fi
 done
 
-if [ "$large_files_present" == true ]; then
+if [[ "${large_files_present}" == true ]]; then
     exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/check-links-non-mkdocs.sh b/doc.zih.tu-dresden.de/util/check-links-non-mkdocs.sh
index a1b28c271d654f117f344490fd3875e70f77b15e..587948b7a4ac5a53ee27ce0d320bf6011c64de3d 100755
--- a/doc.zih.tu-dresden.de/util/check-links-non-mkdocs.sh
+++ b/doc.zih.tu-dresden.de/util/check-links-non-mkdocs.sh
@@ -11,8 +11,8 @@
 set -eo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-basedir=`dirname "$basedir"`
+basedir=`dirname "${scriptpath}"`
+basedir=`dirname "${basedir}"`
 
 usage() {
   cat <<-EOF
@@ -24,33 +24,33 @@ EOF
 }
 
 mlc=markdown-link-check
-if ! command -v $mlc &> /dev/null; then
-  echo "INFO: $mlc not found in PATH (global module)"
-  mlc=./node_modules/markdown-link-check/$mlc
-  if ! command -v $mlc &> /dev/null; then
-    echo "INFO: $mlc not found (local module)"
+if ! command -v ${mlc} &> /dev/null; then
+  echo "INFO: ${mlc} not found in PATH (global module)"
+  mlc=./node_modules/markdown-link-check/${mlc}
+  if ! command -v ${mlc} &> /dev/null; then
+    echo "INFO: ${mlc} not found (local module)"
     exit 1
   fi
 fi
 
-echo "mlc: $mlc"
+echo "mlc: ${mlc}"
 
-LINK_CHECK_CONFIG="$basedir/util/link-check-config.json"
-if [ ! -f "$LINK_CHECK_CONFIG" ]; then
-  echo $LINK_CHECK_CONFIG does not exist
+LINK_CHECK_CONFIG="${basedir}/util/link-check-config.json"
+if [[ ! -f "${LINK_CHECK_CONFIG}" ]]; then
+  echo ${LINK_CHECK_CONFIG} does not exist
   exit 1
 fi
 
 branch="preview"
-if [ -n "$CI_MERGE_REQUEST_TARGET_BRANCH_NAME" ]; then
-    branch="origin/$CI_MERGE_REQUEST_TARGET_BRANCH_NAME"
+if [[ -n "${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" ]]; then
+    branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}"
 fi
 
 function checkSingleFile(){
   theFile="$1"
-  if [ -e "$theFile" ]; then
-    echo "Checking links in $theFile"
-    if ! $mlc -q -c "$LINK_CHECK_CONFIG" -p "$theFile"; then
+  if [[ -e "${theFile}" ]]; then
+    echo "Checking links in ${theFile}"
+    if ! ${mlc} -q -c "${LINK_CHECK_CONFIG}" -p "${theFile}"; then
       return 1
     fi
   fi
@@ -60,30 +60,30 @@ function checkSingleFile(){
 function checkFiles(){
 any_fails=false
 echo "Check files:"
-echo "$files"
+echo "${files}"
 echo ""
-for f in $files; do
-  if ! checkSingleFile "$f"; then
+for f in ${files}; do
+  if ! checkSingleFile "${f}"; then
     any_fails=true
   fi
 done
 
-if [ "$any_fails" == true ]; then
+if [[ "${any_fails}" == true ]]; then
     exit 1
 fi
 }
 
 function checkAllFiles(){
-files=$(git ls-tree --full-tree -r --name-only HEAD $basedir/ | grep '.md$' || true)
+files=$(git ls-tree --full-tree -r --name-only HEAD ${basedir}/ | grep '.md$' || true)
 checkFiles
 }
 
 function checkChangedFiles(){
-files=$(git diff --name-only "$(git merge-base HEAD "$branch")" | grep '.md$' || true)
+files=$(git diff --name-only "$(git merge-base HEAD "${branch}")" | grep '.md$' || true)
 checkFiles
 }
 
-if [ $# -eq 1 ]; then
+if [[ $# -eq 1 ]]; then
   case $1 in
   help | -help | --help)
     usage
@@ -96,7 +96,7 @@ if [ $# -eq 1 ]; then
     checkSingleFile "$1"
   ;;
   esac
-elif [ $# -eq 0 ]; then
+elif [[ $# -eq 0 ]]; then
   checkChangedFiles
 else
   usage
diff --git a/doc.zih.tu-dresden.de/util/check-links.sh b/doc.zih.tu-dresden.de/util/check-links.sh
index ca91a0212403a4c918b6fb115a21920c098dc545..c876dcd78807a9e70758cdad396c370bb3425e13 100755
--- a/doc.zih.tu-dresden.de/util/check-links.sh
+++ b/doc.zih.tu-dresden.de/util/check-links.sh
@@ -38,7 +38,7 @@ while getopts ":a" option; do
 done
 
 # Switch for wikiscript
-if [ -d "doc.zih.tu-dresden.de" ]; then
+if [[ -d "doc.zih.tu-dresden.de" ]]; then
   cd doc.zih.tu-dresden.de
 fi
 
diff --git a/doc.zih.tu-dresden.de/util/check-spelling.sh b/doc.zih.tu-dresden.de/util/check-spelling.sh
index d97f93e20df73b9ea47e501e7196f605f0cacd48..7c3978dcf2487dd5a18b68a835e9f4c446e2e6bb 100755
--- a/doc.zih.tu-dresden.de/util/check-spelling.sh
+++ b/doc.zih.tu-dresden.de/util/check-spelling.sh
@@ -3,9 +3,9 @@
 set -euo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-basedir=`dirname "$basedir"`
-wordlistfile=$(realpath $basedir/wordlist.aspell)
+basedir=`dirname "${scriptpath}"`
+basedir=`dirname "${basedir}"`
+wordlistfile=$(realpath ${basedir}/wordlist.aspell)
 branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-preview}"
 files_to_skip=(doc.zih.tu-dresden.de/docs/accessibility.md doc.zih.tu-dresden.de/docs/data_protection_declaration.md doc.zih.tu-dresden.de/docs/legal_notice.md doc.zih.tu-dresden.de/docs/access/key_fingerprints.md)
 aspellmode=
@@ -19,12 +19,12 @@ usage: $0 [file | -a]
 If file is given, outputs all words of the file, that the spell checker cannot recognize.
 If parameter -a (or --all) is given instead of the file, checks all markdown files.
 Otherwise, checks whether any changed file contains more unrecognizable words than before the change.
-If you are sure a word is correct, you can put it in $wordlistfile.
+If you are sure a word is correct, you can put it in ${wordlistfile}.
 EOF
 }
 
 function getAspellOutput(){
-  aspell -p "$wordlistfile" --ignore 2 -l en_US $aspellmode list | sort -u
+  aspell -p "${wordlistfile}" --ignore 2 -l en_US ${aspellmode} list | sort -u
 }
 
 function getNumberOfAspellOutputLines(){
@@ -34,7 +34,7 @@ function getNumberOfAspellOutputLines(){
 function isWordlistSorted(){
   #Unfortunately, sort depends on locale and docker does not provide much.
   #Therefore, it uses bytewise comparison. We avoid problems with the command tr.
-  if sed 1d "$wordlistfile" | tr [:upper:] [:lower:] | sort -C; then
+  if sed 1d "${wordlistfile}" | tr [:upper:] [:lower:] | sort -C; then
     return 1
   fi
   return 0
@@ -48,26 +48,26 @@ function checkAllFiles(){
   any_fails=false
 
   if isWordlistSorted; then
-    echo "Unsorted wordlist in $wordlistfile"
+    echo "Unsorted wordlist in ${wordlistfile}"
     any_fails=true
   fi
 
-  files=$(git ls-tree --full-tree -r --name-only HEAD $basedir/ | grep .md)
+  files=$(git ls-tree --full-tree -r --name-only HEAD ${basedir}/ | grep .md)
   while read file; do
-    if [ "${file: -3}" == ".md" ]; then
+    if [[ "${file: -3}" == ".md" ]]; then
       if shouldSkipFile ${file}; then
-        echo "Skip $file"
+        echo "Skip ${file}"
       else
-        echo "Check $file"
-        echo "-- File $file"
-        if { cat "$file" | getAspellOutput | tee /dev/fd/3 | grep -xq '.*'; } 3>&1; then
+        echo "Check ${file}"
+        echo "-- File ${file}"
+        if { cat "${file}" | getAspellOutput | tee /dev/fd/3 | grep -xq '.*'; } 3>&1; then
           any_fails=true
         fi
       fi
     fi
-  done <<< "$files"
+  done <<< "${files}"
 
-  if [ "$any_fails" == true ]; then
+  if [[ "${any_fails}" == true ]]; then
     return 1
   fi
   return 0
@@ -77,54 +77,54 @@ function isMistakeCountIncreasedByChanges(){
   any_fails=false
 
   if isWordlistSorted; then
-    echo "Unsorted wordlist in $wordlistfile"
+    echo "Unsorted wordlist in ${wordlistfile}"
     any_fails=true
   fi
 
-  source_hash=`git merge-base HEAD "$branch"`
+  source_hash=`git merge-base HEAD "${branch}"`
   #Remove everything except lines beginning with --- or +++
-  files=`git diff $source_hash | sed -E -n 's#^(---|\+\+\+) ((/|./)[^[:space:]]+)$#\2#p'`
-  #echo "$files"
+  files=`git diff ${source_hash} | sed -E -n 's#^(---|\+\+\+) ((/|./)[^[:space:]]+)$#\2#p'`
+  #echo "${files}"
   #echo "-------------------------"
   #Assume that we have pairs of lines (starting with --- and +++).
   while read oldfile; do
     read newfile
-    if [ "${newfile: -3}" == ".md" ]; then
+    if [[ "${newfile: -3}" == ".md" ]]; then
       if shouldSkipFile ${newfile:2}; then
-        echo "Skip $newfile"
+        echo "Skip ${newfile}"
       else
-        echo "Check $newfile"
-        if [ "$oldfile" == "/dev/null" ]; then
+        echo "Check ${newfile}"
+        if [[ "${oldfile}" == "/dev/null" ]]; then
           #Added files should not introduce new spelling mistakes
           previous_count=0
         else
-          previous_count=`git show "$source_hash:${oldfile:2}" | getNumberOfAspellOutputLines`
+          previous_count=`git show "${source_hash}:${oldfile:2}" | getNumberOfAspellOutputLines`
         fi
-        if [ "$newfile" == "/dev/null" ]; then
+        if [[ "${newfile}" == "/dev/null" ]]; then
           #Deleted files do not contain any spelling mistakes
           current_count=0
         else
           #Remove the prefix "b/"
           newfile=${newfile:2}
-          current_count=`cat "$newfile" | getNumberOfAspellOutputLines`
+          current_count=`cat "${newfile}" | getNumberOfAspellOutputLines`
         fi
-        if [ $current_count -gt $previous_count ]; then
-          echo "-- File $newfile"
-          echo "Change increases spelling mistake count (from $previous_count to $current_count), misspelled/unknown words:"
-          cat "$newfile" | getAspellOutput
+        if [[ ${current_count} -gt ${previous_count} ]]; then
+          echo "-- File ${newfile}"
+          echo "Change increases spelling mistake count (from ${previous_count} to ${current_count}), misspelled/unknown words:"
+          cat "${newfile}" | getAspellOutput
           any_fails=true
         fi
       fi
     fi
-  done <<< "$files"
+  done <<< "${files}"
 
-  if [ "$any_fails" == true ]; then
+  if [[ "${any_fails}" == true ]]; then
     return 1
   fi
   return 0
 }
 
-if [ $# -eq 1 ]; then
+if [[ $# -eq 1 ]]; then
   case $1 in
   help | -help | --help)
     usage
@@ -137,7 +137,7 @@ if [ $# -eq 1 ]; then
     cat "$1" | getAspellOutput
   ;;
   esac
-elif [ $# -eq 0 ]; then
+elif [[ $# -eq 0 ]]; then
   isMistakeCountIncreasedByChanges
 else
   usage
diff --git a/doc.zih.tu-dresden.de/util/check-templated-code-snippets.sh b/doc.zih.tu-dresden.de/util/check-templated-code-snippets.sh
index 2eecc039b7a3611eeef9b4b264bc0185c6fcad39..d5b567e5a7232bd955fff632e358daac6e2ff10a 100755
--- a/doc.zih.tu-dresden.de/util/check-templated-code-snippets.sh
+++ b/doc.zih.tu-dresden.de/util/check-templated-code-snippets.sh
@@ -3,9 +3,9 @@
 set -eo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-pythonscript="$basedir/check-templated-code-snippets.py"
-basedir=`dirname "$basedir"`
+basedir=`dirname "${scriptpath}"`
+pythonscript="${basedir}/check-templated-code-snippets.py"
+basedir=`dirname "${basedir}"`
 
 function usage() {
   cat <<-EOF
@@ -20,7 +20,7 @@ EOF
 branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-preview}"
 
 # Options
-if [ $# -eq 1 ]; then
+if [[ $# -eq 1 ]]; then
   case $1 in
   help | -help | --help)
     usage
@@ -28,29 +28,29 @@ if [ $# -eq 1 ]; then
   ;;
   -a | --all)
     echo "Search in all markdown files."
-    files=$(git ls-tree --full-tree -r --name-only HEAD $basedir/ | grep .md)
+    files=$(git ls-tree --full-tree -r --name-only HEAD ${basedir}/ | grep .md)
   ;;
   *)
     files="$1"
   ;;
   esac
-elif [ $# -eq 0 ]; then
+elif [[ $# -eq 0 ]]; then
   echo "Search in git-changed files."
-  files=`git diff --name-only "$(git merge-base HEAD "$branch")" | grep .md || true`
+  files=`git diff --name-only "$(git merge-base HEAD "${branch}")" | grep .md || true`
 else
   usage
 fi
 
 all_ok=''
-for f in $files; do
-if ! $pythonscript $f; then
-all_ok='no'
-fi
+for f in ${files}; do
+  if ! ${pythonscript} ${f}; then
+    all_ok='no'
+  fi
 done
 
-if [ -z "$all_ok" ]; then
-echo "Success!"
+if [[ -z "${all_ok}" ]]; then
+  echo "Success!"
 else
-echo "Fail!"
-exit 1
+  echo "Fail!"
+  exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/create-issues-all-pages.sh b/doc.zih.tu-dresden.de/util/create-issues-all-pages.sh
index 0d41c7bd1c8446c252dd53818a02a1c6976dae7a..9e3b15beef0a5992cffccb0014959e6781876371 100755
--- a/doc.zih.tu-dresden.de/util/create-issues-all-pages.sh
+++ b/doc.zih.tu-dresden.de/util/create-issues-all-pages.sh
@@ -3,15 +3,15 @@
 set -eo pipefail
 
 scriptpath=${BASH_SOURCE[0]}
-basedir=`dirname "$scriptpath"`
-basedir=`dirname "$basedir"`
+basedir=`dirname "${scriptpath}"`
+basedir=`dirname "${basedir}"`
 
-files=$(git ls-tree --full-tree -r --name-only HEAD $basedir/ | grep '\.md$' | grep -v '/archive/' || true)
+files=$(git ls-tree --full-tree -r --name-only HEAD ${basedir}/ | grep '\.md$' | grep -v '/archive/' || true)
 
 description=""
-for f in $files; do
-description="$description- [ ] $f
+for f in ${files}; do
+description="${description}- [ ] ${f}
 "
 done
 
-curl --request POST --header "PRIVATE-TOKEN: $SCHEDULED_PAGE_CHECK_PAT" --form 'title="Regular check of all pages"' --form "description=\"$description\"" --form "labels=Bot" https://gitlab.hrz.tu-chemnitz.de/api/v4/projects/${CI_PROJECT_ID}/issues
+curl --request POST --header "PRIVATE-TOKEN: ${SCHEDULED_PAGE_CHECK_PAT}" --form 'title="Regular check of all pages"' --form "description=\"${description}\"" --form "labels=Bot" https://gitlab.hrz.tu-chemnitz.de/api/v4/projects/${CI_PROJECT_ID}/issues
diff --git a/doc.zih.tu-dresden.de/util/grep-forbidden-patterns.sh b/doc.zih.tu-dresden.de/util/grep-forbidden-patterns.sh
index dba8b694d3dcbc6a26132477170b610736f0da0d..876fea08c247b7f9741176006fddb9ba9d74f4d8 100755
--- a/doc.zih.tu-dresden.de/util/grep-forbidden-patterns.sh
+++ b/doc.zih.tu-dresden.de/util/grep-forbidden-patterns.sh
@@ -74,7 +74,7 @@ doc.zih.tu-dresden.de/docs/contrib/content_rules.md
 i	work[ -]\+space"
 
 function grep_exceptions () {
-  if [ $# -gt 0 ]; then
+  if [[ $# -gt 0 ]]; then
     firstPattern=$1
     shift
     grep -v "${firstPattern}" | grep_exceptions "$@"
@@ -96,10 +96,10 @@ function check_file(){
     while IFS=$'\t' read -r -a exceptionPatternsArray; do
       # Prevent patterns from being printed when the script is invoked with
       # default arguments.
-      if [ ${verbose} = true ]; then
+      if [[ ${verbose} == true ]]; then
         echo "  Pattern: ${pattern}${skipping}"
       fi
-      if [ -z "${skipping}" ]; then
+      if [[ -z "${skipping}" ]]; then
         grepflag=
         case "${flags}" in
           "i")
@@ -114,7 +114,7 @@ function check_file(){
           ((cnt=cnt+$number_of_matches))
           # prevent messages when silent=true,
           # only files, pattern matches and the summary are printed
-          if [ ${silent} = false ]; then
+          if [[ ${silent} == false ]]; then
             echo "    ${message}"
           fi
         fi
@@ -176,10 +176,10 @@ done
 
 branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME:-preview}"
 
-if [ ${all_files} = true ]; then
+if [[ ${all_files} == true ]]; then
   echo "Search in all markdown files."
   files=$(git ls-tree --full-tree -r --name-only HEAD ${basedir}/ | grep .md)
-elif [[ ! -z ${file} ]]; then
+elif [[ ! -z "${file}" ]]; then
   files=${file}
 else
   echo "Search in git-changed files."
@@ -188,16 +188,16 @@ fi
 
 #Prevent files from being printed when the script is invoked with default
 # arguments.
-if [ ${verbose} = true ]; then
-echo "... ${files} ..."
+if [[ ${verbose} == true ]]; then
+  echo "... ${files} ..."
 fi
 cnt=0
-if [[ ! -z ${file} ]]; then
-  check_file ${file}
+if [[ ! -z "${file}" ]]; then
+  check_file "${file}"
 else
   for f in ${files}; do
-    if [ "${f: -3}" == ".md" -a -f "${f}" ]; then
-      check_file ${f}
+    if [[ "${f: -3}" == ".md" && -f "${f}" ]]; then
+      check_file "${f}"
     fi
   done
 fi
@@ -211,6 +211,6 @@ case ${cnt} in
     echo "Forbidden Patterns: ${cnt} matches found"
   ;;
 esac
-if [ ${cnt} -gt 0 ]; then
+if [[ ${cnt} -gt 0 ]]; then
   exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/lint-changes.sh b/doc.zih.tu-dresden.de/util/lint-changes.sh
index 05ee5784468bed8d49adbbad8c9389bd3823590b..0e4013784784d2402f0f938cf7efebbdca15f59d 100755
--- a/doc.zih.tu-dresden.de/util/lint-changes.sh
+++ b/doc.zih.tu-dresden.de/util/lint-changes.sh
@@ -3,25 +3,25 @@
 set -euo pipefail
 
 branch="preview"
-if [ -n "$CI_MERGE_REQUEST_TARGET_BRANCH_NAME" ]; then
-    branch="origin/$CI_MERGE_REQUEST_TARGET_BRANCH_NAME"
+if [[ -n "${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}" ]]; then
+    branch="origin/${CI_MERGE_REQUEST_TARGET_BRANCH_NAME}"
 fi
 
 configfile=$(dirname $0)/../.markdownlintrc
-echo "config: $configfile"
+echo "config: ${configfile}"
 
 any_fails=false
 
-files=$(git diff --name-only "$(git merge-base HEAD "$branch")")
-for f in $files; do
-    if [ "${f: -3}" == ".md" ]; then
-        echo "Linting $f"
-        if ! markdownlint -c $configfile "$f"; then
+files=$(git diff --name-only "$(git merge-base HEAD "${branch}")")
+for f in ${files}; do
+    if [[ "${f: -3}" == ".md" ]]; then
+        echo "Linting ${f}"
+        if ! markdownlint -c ${configfile} "${f}"; then
             any_fails=true
         fi
     fi
 done
 
-if [ "$any_fails" == true ]; then
+if [[ "${any_fails}" == true ]]; then
     exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/test-grep-forbidden-patterns.sh b/doc.zih.tu-dresden.de/util/test-grep-forbidden-patterns.sh
index 1e98caf528d9b1a1d640e9dd3e5c7dc23ec937ea..f9af81cf5541e8a49d69e23c2453b587386556fd 100755
--- a/doc.zih.tu-dresden.de/util/test-grep-forbidden-patterns.sh
+++ b/doc.zih.tu-dresden.de/util/test-grep-forbidden-patterns.sh
@@ -4,10 +4,10 @@ expected_match_count=32
 
 number_of_matches=$(bash ./doc.zih.tu-dresden.de/util/grep-forbidden-patterns.sh -f doc.zih.tu-dresden.de/util/grep-forbidden-patterns.testdoc -c -c | grep "Forbidden Patterns:" | sed -e 's/.*: //' | sed -e 's/ matches.*//')
 
-if [ $number_of_matches -eq $expected_match_count ]; then
+if [[ ${number_of_matches} -eq ${expected_match_count} ]]; then
 	echo "Test OK"
 	exit 0
 else
-	echo "Test failed: $expected_match_count matches expected, but only $number_of_matches found"
+	echo "Test failed: ${expected_match_count} matches expected, but only ${number_of_matches} found"
 	exit 1
 fi
diff --git a/doc.zih.tu-dresden.de/util/check-code-style.sh b/doc.zih.tu-dresden.de/util/check-code-style.sh
index 8a06519389846bcff38c4d9c22d23c4a1273ff50..7001cb9e03a782e80697c032647b401d1cdd7c0a 100755
--- a/doc.zih.tu-dresden.de/util/check-code-style.sh
+++ b/doc.zih.tu-dresden.de/util/check-code-style.sh
@@ -110,7 +110,7 @@ fi
 
 any_fails=false
 
-for file in $files; do
+for file in ${files}; do
   # Skip the check of this current ($0) script.
   if echo "${file}" | grep -qP "check-code-style.sh$"; then
     continue
@@ -130,12 +130,12 @@ for file in $files; do
     any_fails=true
   fi
 
   # Line length less than 80char length
   file_ext="${file##*.}"
   if [[ "${file_ext}" == "sh" ]]; then
     #echo "Checking for max line length..."
-    pattern='^.{80}.*$'
-    warning="Recommended maximum line length is 80 characters."
+    pattern='^.{100}.*$'
+    warning="Recommended maximum line length is 100 characters."
     if pattern_matches "${file}" "${pattern}" "${warning}"; then
       any_fails=true
     fi
@@ -130,12 +130,12 @@ for file in $files; do
   fi
 
-  # Line length less than 80char length
+  # Line length less than 100 char length
   file_ext="${file##*.}"
   if [[ "${file_ext}" == "sh" ]]; then